@@ -32,42 +32,46 @@ print_r ($entry->module);
 $wordcount = $this->GetPreference('key_number','20');
 $wordlength = $this->GetPreference('key_length','4');
 $worddensity = $this->GetPreference('key_density','3');
+$checkContent = $curcontent->GetPropertyValue('content_en');
 
-$keywords = $curcontent->GetPropertyValue('content_en');
-$keywords = preg_replace('/[\n\r]/','',$keywords);
-$keywords = preg_replace('/[\.\,]/','',$keywords);
-$keywords = str_replace('><','> <',$keywords);
-$keywords = strtolower($keywords);
-$keywords = strip_tags(str_replace('"','',$keywords));
-$keywords = preg_replace('/{.*}/','',$keywords);
-$keywords = preg_replace(array('/&[^\s]*;/'), '', htmlentities($keywords));
+if ($checkContent != '') {
+    $keywords = $curcontent->GetPropertyValue('content_en');
+    $keywords = preg_replace('/[\n\r]/','',$keywords);
+    $keywords = preg_replace('/[\.\,]/','',$keywords);
+    $keywords = str_replace('><','> <',$keywords);
+    $keywords = strtolower($keywords);
+    $keywords = strip_tags(str_replace('"','',$keywords));
+    $keywords = preg_replace('/{.*}/','',$keywords);
+    $keywords = preg_replace(array('/&[^\s]*;/'), '', htmlentities($keywords));
+}
 
 if ($keywords != '') {
     $keywords = explode(' ',$keywords);
 } else {
     $keywords = '';
 }
-foreach ($keywords as $key => $word ) { //Turn Keywords into an array
-    if (strlen($word) >= $wordlength) {
-        $words[] = $word;
+if ($keywords != '') {
+    foreach ($keywords as $key => $word ) { //Turn Keywords into an array
+        if (strlen($word) >= $wordlength) {
+            $words[] = $word;
+        }
     }
-}
 
+    $keywordsskip = $this->GetPreference('keyskip_title',''); //Get the list of STOP words
+    $keywordsskip = str_replace(' ','',$keywordsskip);
+    $keywordsskip = explode(',',$keywordsskip);
 
-$keywordsskip = $this->GetPreference('keyskip_title',''); //Get the list of STOP words
-$keywordsskip = str_replace(' ','',$keywordsskip);
-$keywordsskip = explode(',',$keywordsskip);
+    foreach ($keywordsskip as $skipkey => $skipword ) { //Turn STOP words into an array
+        $skipwords[] = $skipword;
+    }
 
-foreach ($keywordsskip as $skipkey => $skipword ) { //Turn STOP words into an array
-    $skipwords[] = $skipword;
-}
+    $keywordsdefault = $this->GetPreference('key_default',''); //Get the list of Default keywords to include
+    $keywordsdefault = str_replace(' ','',$keywordsdefault);
+    $keywordsdefault = explode(',',$keywordsdefault);
 
-$keywordsdefault = $this->GetPreference('key_default',''); //Get the list of Default keywords to include
-$keywordsdefault = str_replace(' ','',$keywordsdefault);
-$keywordsdefault = explode(',',$keywordsdefault);
-
-foreach ($keywordsdefault as $defkey => $defword ) { //Turn Default keywords into an array
-    $defwords[] = $defword;
+    foreach ($keywordsdefault as $defkey => $defword ) { //Turn Default keywords into an array
+        $defwords[] = $defword;
+    }
 }
 
 $keywordsskip = preg_split("/[\s,]+/", $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very'));
